@@ -20,29 +20,31 @@
 #endif
 
 #include <iostream>
+#include <fstream>
 #include <stdlib.h>
 
-#include <ann_cybenko.h>
+#include <ann_term.h>
+#include <ann_parser_ws.h>
 #include <ann_w_step.h>
 #include <ann_w_mntm.h>
 #include <ann_log_io.h>
-#include <ann_term.h>
-#include <ann_ds_ws.h>
+#include <ann_log_lazy.h>
 #include <ann_ds_tee.h>
 #include <ann_ds_frame.h>
 #include <ann_ds_xpm.h>
+#include <ann_ds_out.h>
 #include <ann_sink_ws.h>
 #include <ann_sink_log.h>
 #include <ann_sink_xpm.h>
 #include <ann_ds_rnd.h>
-#include <ann_ne_bprop.h>
-#include <ann_ds_out.h>
+#include <ann_nfb_bprop.h>
+#include <ann_nfb_mlayer.h>
+#include <ann_nfb_perc.h>
 #include <ann_to_offline.h>
 #include <ann_to_online.h>
-#include <ann_log_lazy.h>
-#include <fstream>
+#include <ann_cybenko.h>
 
-#define INPUT_FILE "/home/bartek/src/ann-0.3/test.txt"
+#define INPUT_FILE "test.txt"
 
 void
 sample_Cybenko(ANN::Log &log)
@@ -63,12 +65,16 @@ sample_Cybenko(ANN::Log &log)
    */
    
   std::ifstream fdata(INPUT_FILE);
-  ANN::DS_ws ds_ws(fdata);
-  if (ds_ws.get_length()!=ANN::size_max) for (i=0; i<ds_ws.get_length(); ++i)
+  ANN::Parser_ws parser;
+  parser(fdata);
+  ANN::DS_buff ds_in(parser.build(0));
+  ANN::DS_buff ds_des_out(parser.build(1));
+  if (ds_in.get_length()!=ANN::size_max) for (i=0; i<ds_in.get_length(); ++i)
   {
-    log.log(ds_ws.term(),"input  pattern");
-    if (ds_ws.des_output()) log.log(ds_ws.des_output()->term(),"output pattern");
-    ds_ws.next();
+    log.log(ds_in.term(),"input  pattern");
+    log.log(ds_des_out.term(),"output pattern");
+    ds_in.feed();
+    ds_des_out.feed();
   }
   
   /*
@@ -94,7 +100,7 @@ sample_Cybenko(ANN::Log &log)
    * it with a brand new created Cybenko's network
    */
    
-  ANN::NE_bprop sample // declare evaluator
+  ANN::NFB_bprop sample // declare evaluator
   (
     *ANN::create_Cybenko // create neural element to evluate
     (
@@ -107,6 +113,8 @@ sample_Cybenko(ANN::Log &log)
       false                // the question is whether to use bias,
                            // the answer here is: false
     ),                   // otehr parameters of evaluator:
+    ds_des_out,          // desired values -- for input sequence look into
+                         // TO_offline constructor
     .01,                 // stop training when the error drops below .01
     &lazy2               // log effects of training every 20 epochs
   );
@@ -114,24 +122,22 @@ sample_Cybenko(ANN::Log &log)
   /*
    * Training
    */
-   
-  /* create the trainer, give it data and a log to report */ 
-  ANN::TO_offline trainer(ds_ws,&lazy5);
-  /* who is going to be tought */
-  trainer.act_on(sample);
+
+  /* create the trainer, give it pupil, data and a log to report */
+  ANN::TO_offline trainer(sample,ds_in,&lazy5);
   /* randomize weights */
   trainer.randomize();
   /* train no more then 1000 epochs */
-  trainer.train(1000);
+  trainer.adapt_for(1000);
 
   /*
    * Produce results
    */
-   
+
   /* This DS forces neural element to produce outputs on inputs from some
    * other DS, produced outputs are data provided by this DS, desired output
    * co-sequence stays untouched */
-  ANN::DS_out   ds_out(ds_ws,sample);
+  ANN::DS_out   ds_out(ds_in,sample);
   /* This sink stores data in a given log */
   ANN::Sink_log sink_log(log);
   /* Data goes through this DS unmodified, its role is to store it in a sink,
@@ -140,15 +146,14 @@ sample_Cybenko(ANN::Log &log)
   (
     ds_out,   // source of the data
     sink_log, // where to dump copies
-    "output", // tag for main sequence
-    "desird"  // tag for the sequence of desired outputs (if still there)
+    "output"  // tag for main sequence
   );
   /* I cannot imagine any serios work without initial reset, reboot, reload
    * or something */
   ds_tee.reset();
   /* If the sequence is finited ... */
   if (ds_tee.get_length()!=ANN::size_max)
-    for (i=1; i<ds_tee.get_length(); ++i) ds_tee.next();
+    for (i=1; i<ds_tee.get_length(); ++i) ds_tee.feed();
       /* ... walk through it, forcing it to produce outputs of the given neural
        * element (DS_out) and then dump these outputs to the log (DS_tee) */
 }
@@ -162,7 +167,7 @@ sample_codec424(ANN::Log &log)
    * creating lazy logs, that filter events and log them every N-th
    * epoch to the main log
    */
-   
+
   ANN::Log_lazy lazy2(log,20); // the N is 20
   ANN::Log_lazy lazy3(log,30);
   ANN::Log_lazy lazy5(log,50);
@@ -170,34 +175,38 @@ sample_codec424(ANN::Log &log)
   /*
    * reading data in from file, then reporting them in the log
    */
-  
+
   std::ifstream fdata(INPUT_FILE);
-  ANN::DS_ws ds_ws(fdata);
-  if (ds_ws.get_length()!=ANN::size_max) for (i=0; i<ds_ws.get_length(); ++i)
+  ANN::Parser_ws parser;
+  parser(fdata);
+  ANN::DS_buff ds_in(parser.build(0));
+  ANN::DS_buff ds_des_out(parser.build(1));
+  if (ds_in.get_length()!=ANN::size_max) for (i=0; i<ds_in.get_length(); ++i)
   {
-    log.log(ds_ws.term(),"input  pattern");
-    if (ds_ws.des_output()) log.log(ds_ws.des_output()->term(),"output pattern");
-    ds_ws.next();
+    log.log(ds_in.term(),"input  pattern");
+    log.log(ds_des_out.term(),"output pattern");
+    ds_in.feed();
+    ds_des_out.feed();
   }
-  
+
   /*
    * Preparation of a weight engine factory
    */
 
   /* 1. parameters of weight group */
-  ANN::WGC_step   gr_wg_cmn
+  ANN::WGC_step    gr_wg_cmn
   (
     lazy5, // dump weight values to the log every 50 epochs
     10.0   // modify weights using 10.0 step (very fast, but the network is
   );       // small, problem not so complex - see further for the network
            // structure)
   /* 2. weight group factory takes parameters for groups to be created */
-  ANN::WG_step_F  gr_wg_f(gr_wg_cmn);
+  ANN::WG_step_F   gr_wg_f(gr_wg_cmn);
   /* 3. parameters for weights to be created - plain gradient weights
    * need to have appropriate weight group factory */
-  ANN::WC_step    gr_w_cmn(gr_wg_f);
+  ANN::WC_step     gr_w_cmn(gr_wg_f);
   /* 4. weight factory takes parameters for weights to be created */
-  ANN::W_step_F   gr_w_f(gr_w_cmn);
+  ANN::W_step_F    gr_w_f(gr_w_cmn);
 
   /*
    * Network creation
@@ -205,9 +214,9 @@ sample_codec424(ANN::Log &log)
 
   /* Initial data for multilayer perceptron: number of inputs and a label
    * labels for the layers will be derived from the given label */
-  ANN::Init       inst(4,"codec424_net");
+  ANN::Init        inst(4,"codec424_net");
   /* Parameters for the first (and the only) hidden layer */
-  ANN::NEC_perc   hid_par
+  ANN::NFBC_perc   hid_par
   (
     2,                   // number of neurons in the layer
     &lazy3,              // where to log outputs from neurons
@@ -217,42 +226,41 @@ sample_codec424(ANN::Log &log)
   );                     // bias neurons are never implemented as separate
                          // objects
   /* Parameters for the last - output layer, see above for explanations*/
-  ANN::NEC_perc   out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
+  ANN::NFBC_perc  out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
   /* Prepare array of layer factories */
-  ANN::NE_perc_F *factory[]=
+  ANN::NFB_perc_F *factory[]=
   {
-    new ANN::NE_perc_F(hid_par),
-    new ANN::NE_perc_F(out_par),
+    new ANN::NFB_perc_F(hid_par),
+    new ANN::NFB_perc_F(out_par),
   };
   /* Create element evaluating outputs from multilayer network, supply
    * it with a brand new created multilayer network */
-  ANN::NE_bprop   sample
+  ANN::NFB_bprop sample
   (
-    *new ANN::NE_mlayer // first we create an elemnt to be evaluated
+    *new ANN::NFB_mlayer // first we create an elemnt to be evaluated
     (                   // here it is a multilayer network
       &inst,    // initial data
       log,      // where to report important events
       factory,  // how to create layers - pointer to an array of factories
       factory+2 // how long is the array
-    ),     // other paramters of evaluator
-    .01,   // when errors drops below 0.01 assume the network is trained
-    &lazy2 // log to report training progress
+    ),          // other paramters of evaluator
+    ds_des_out, // desired output values to be tought
+    .01,        // when errors drops below 0.01 assume the network is trained
+    &lazy2      // log to report training progress
   );
   /* When the neural elements are created we need the factories no more */
-  ANN::NE_mlayer::drop_f(factory,factory+2);
+  ANN::NFB_mlayer::drop_f(factory,factory+2);
 
   /*
    * Training
    */
 
-  /* create the trainer, give it data and a log to report */  
-  ANN::TO_offline trainer(ds_ws,&lazy5);
-  /* who is going to be tought */
-  trainer.act_on(sample);
+  /* create the trainer, give it pupil, data and a log to report */
+  ANN::TO_offline trainer(sample,ds_in,&lazy5);
   /* randomize weights */
   trainer.randomize();
   /* train no more then 1000 epochs */
-  trainer.train(1000);
+  trainer.adapt_for(1000);
 
   /*
    * Produce results
@@ -261,13 +269,13 @@ sample_codec424(ANN::Log &log)
   /* This DS forces neural element to produce outputs on inputs from some
    * other DS, produced outputs are data provided by this DS, desired output
    * co-sequence stays untouched */
-  ANN::DS_out   ds_out(ds_ws,sample);
+  ANN::DS_out   ds_out(ds_in,sample);
   /* This sink stores data in a given log */
   ANN::Sink_log sink_log(log);
   /* Store data from a given DS (in this case DS_out forces some neural element
    * to produce outputs, so the outputs from that element are stored) using
    * given tags for main sequence and co-sequence with desired outputs */
-  sink_log.store(ds_out,"output","desird");
+  sink_log.store(ds_out,"output");
 }
 
 void
@@ -276,26 +284,30 @@ sample_codec424_mntm(ANN::Log &log)
   /*
    * For comments see above, only first used elements are explained
    */
-   
+
   size_t        i;
   ANN::Log_lazy lazy2(log,20);
   ANN::Log_lazy lazy3(log,30);
   ANN::Log_lazy lazy5(log,50);
   std::ifstream fdata(INPUT_FILE);
-  ANN::DS_ws ds_ws(fdata);
-  if (ds_ws.get_length()!=ANN::size_max) for (i=0; i<ds_ws.get_length(); ++i)
+  ANN::Parser_ws parser;
+  parser(fdata);
+  ANN::DS_buff ds_in(parser.build(0));
+  ANN::DS_buff ds_des_out(parser.build(1));
+  if (ds_in.get_length()!=ANN::size_max) for (i=0; i<ds_in.get_length(); ++i)
   {
-    log.log(ds_ws.term(),"input  pattern");
-    if (ds_ws.des_output()) log.log(ds_ws.des_output()->term(),"output pattern");
-    ds_ws.next();
+    log.log(ds_in.term(),"input  pattern");
+    log.log(ds_des_out.term(),"output pattern");
+    ds_in.feed();
+    ds_des_out.feed();
   }
 
   /*
    * Preparation of momentum weight engine factory
    */
-   
+
   /* 1. parameters of weight group */
-  ANN::WGC_mntm   gr_wg_cmn(
+  ANN::WGC_mntm    gr_wg_cmn(
     lazy5, // dump weight values to the log every 50 epochs
     .3,    // gradient step coeficient, call it etha
     .9     // momentum coeficient, call it alpha
@@ -305,34 +317,34 @@ sample_codec424_mntm(ANN::Log &log)
    * weight += delta ;
    */
   /* 2. weight group factory takes parameters for groups to be created */
-  ANN::WG_mntm_F  gr_wg_f(gr_wg_cmn);
+  ANN::WG_mntm_F   gr_wg_f(gr_wg_cmn);
   /* 3. parameters for weights to be created - momentum gradient weights
    * need to have appropriate weight group factory */
-  ANN::WC_mntm    gr_w_cmn(gr_wg_f);
+  ANN::WC_mntm     gr_w_cmn(gr_wg_f);
   /* 4. weight factory takes parameters for weights to be created */
-  ANN::W_mntm_F   gr_w_f(gr_w_cmn);
-  
-  ANN::Init       inst(4,"codec424_net");
-  ANN::NEC_perc   hid_par(2,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
-  ANN::NEC_perc   out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
-  ANN::NE_perc_F *factory[]=
+  ANN::W_mntm_F    gr_w_f(gr_w_cmn);
+
+  ANN::Init        inst(4,"codec424_net");
+  ANN::NFBC_perc   hid_par(2,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
+  ANN::NFBC_perc   out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
+  ANN::NFB_perc_F *factory[]=
   {
-    new ANN::NE_perc_F(hid_par),
-    new ANN::NE_perc_F(out_par),
+    new ANN::NFB_perc_F(hid_par),
+    new ANN::NFB_perc_F(out_par),
   };
-  ANN::NE_bprop   sample(*new ANN::NE_mlayer(&inst,log,factory,factory+2),
-                         .01,&lazy2);
-  ANN::NE_mlayer::drop_f(factory,factory+2);
-  ANN::TO_offline trainer(ds_ws,&lazy5);
-  trainer.act_on(sample);
+  ANN::NFB_bprop  sample(*new ANN::NFB_mlayer(&inst,log,factory,factory+2),
+                         ds_des_out,.01,&lazy2);
+  ANN::NFB_mlayer::drop_f(factory,factory+2);
+  ANN::TO_offline trainer(sample,ds_in,&lazy5);
   trainer.randomize();
-  trainer.train(1000);
-  ANN::DS_out   ds_out(ds_ws,sample);
+  trainer.adapt_for(1000);
+
+  ANN::DS_out   ds_out(ds_in,sample);
   ANN::Sink_log sink_log(log);
   ANN::DS_tee   ds_tee(ds_out,sink_log);
   ds_tee.reset();
   if (ds_tee.get_length()!=ANN::size_max)
-    for (i=1; i<ds_tee.get_length(); ++i) ds_tee.next();
+    for (i=1; i<ds_tee.get_length(); ++i) ds_tee.feed();
 }
 
 void
@@ -341,34 +353,38 @@ sample_codec424_mntm_rnd(ANN::Log &log)
   /*
    * For comments see above, only first used elements are explained
    */
-   
+
   size_t        i;
   ANN::Log_lazy lazy2(log,20);
   ANN::Log_lazy lazy3(log,30);
   ANN::Log_lazy lazy5(log,50);
   std::ifstream fdata(INPUT_FILE);
-  ANN::DS_ws ds_ws(fdata);
-  if (ds_ws.get_length()!=ANN::size_max) for (i=0; i<ds_ws.get_length(); ++i)
+  ANN::Parser_ws parser;
+  parser(fdata);
+  ANN::DS_buff ds_in(parser.build(0));
+  ANN::DS_buff ds_des_out(parser.build(1));
+  if (ds_in.get_length()!=ANN::size_max) for (i=0; i<ds_in.get_length(); ++i)
   {
-    log.log(ds_ws.term(),"input  pattern");
-    if (ds_ws.des_output()) log.log(ds_ws.des_output()->term(),"output pattern");
-    ds_ws.next();
+    log.log(ds_in.term(),"input  pattern");
+    log.log(ds_des_out.term(),"output pattern");
+    ds_in.feed();
+    ds_des_out.feed();
   }
-  ANN::WGC_mntm   gr_wg_cmn(lazy5,.3,.9);
-  ANN::WG_mntm_F  gr_wg_f(gr_wg_cmn);
-  ANN::WC_mntm    gr_w_cmn(gr_wg_f);
-  ANN::W_mntm_F   gr_w_f(gr_w_cmn);
-  ANN::Init       inst(4,"codec424_net");
-  ANN::NEC_perc   hid_par(2,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
-  ANN::NEC_perc   out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
-  ANN::NE_perc_F *factory[]=
+  ANN::WGC_mntm    gr_wg_cmn(lazy5,.3,.9);
+  ANN::WG_mntm_F   gr_wg_f(gr_wg_cmn);
+  ANN::WC_mntm     gr_w_cmn(gr_wg_f);
+  ANN::W_mntm_F    gr_w_f(gr_w_cmn);
+  ANN::Init        inst(4,"codec424_net");
+  ANN::NFBC_perc   hid_par(2,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
+  ANN::NFBC_perc   out_par(4,&lazy3,&gr_w_f,ANN::Act::sigmoidal,true);
+  ANN::NFB_perc_F *factory[]=
   {
-    new ANN::NE_perc_F(hid_par),
-    new ANN::NE_perc_F(out_par),
+    new ANN::NFB_perc_F(hid_par),
+    new ANN::NFB_perc_F(out_par),
   };
-  ANN::NE_bprop   sample(*new ANN::NE_mlayer(&inst,log,factory,factory+2),
-                         .01,&lazy2);
-  ANN::NE_mlayer::drop_f(factory,factory+2);
+  ANN::NFB_bprop  sample(*new ANN::NFB_mlayer(&inst,log,factory,factory+2),
+                         ds_des_out,.01,&lazy2);
+  ANN::NFB_mlayer::drop_f(factory,factory+2);
 
   
   /*
@@ -378,17 +394,16 @@ sample_codec424_mntm_rnd(ANN::Log &log)
   /* Once we want to teach online, data should be randomly reordered every
    * epoch, thus we don't use the the original DS but rather a DS that
    * permutes the data */
-  ANN::DS_rnd     ds_rnd(ds_ws);
-  /* create the trainer, give it data and a log to report */
-  ANN::TO_online  trainer(ds_rnd,&lazy5);  
-  /* who is going to be tought */
-  trainer.act_on(sample);
+  ANN::DS_rnd     ds_rnd(ds_in);
+  /* create the trainer, give it pupil, data and a log to report */
+  ANN::TO_online trainer(sample,ds_rnd,&lazy5);
   /* randomize weights */
   trainer.randomize();
   /* train no more then 1000 epochs */
-  trainer.train(1000);
-  
-  ANN::DS_out   ds_out(ds_ws,sample);
+  trainer.adapt_for(1000);
+
+    
+  ANN::DS_out   ds_out(ds_in,sample);
   std::ofstream fout("wyniki.out");
   ANN::Sink_ws  sink_ws(fout);
   sink_ws.store(ds_out);
@@ -463,7 +478,7 @@ main(int argc, char *argv[])
   /* Backpropagation trained network of 2 sigmoidal hidden and 4 sigmoidal 
    * output neurons. The network has 4 inputs. Weights are updated offline
    * using plain gradient method.
-   */
+   * /
   sample_codec424(log); /**/
   
   /* Backpropagation trained network of 2 sigmoidal hidden and 4 sigmoidal
@@ -475,7 +490,7 @@ main(int argc, char *argv[])
   /* Backpropagation trained network of 2 sigmoidal hidden and 4 sigmoidal
    * output neurons. The network has 4 inputs. Weights are updated online
    * using momentum gradient method. Input patterns are permuted every epoch.
-   * /
+   */
   sample_codec424_mntm_rnd(log); /**/
 
   /* Example of loading XPM image, making a sequnce of subframes of it and
