@@ -22,13 +22,11 @@
 
 #include <ann_loc.h>
 #include <ann_ds.h>
-#include <ann_tc.h>
 
 namespace ANN
 {
 
-  class DS_buff;      /* buffered data source */
-  class DS_buff_des;  /* buffered data source for desired output */
+  class DS_buff; /* buffered data source */
 
   //               //
  // class DS_buff //
@@ -37,74 +35,57 @@ namespace ANN
   class DS_buff : public virtual DS
   {
   private:
-    TS           data;
+    TS          *data;
+    Size         lengths;
+    Term         current;
     Loc          loc;
-    size_t       current;
-    static Term  nan;
-
-    DS_buff(const DS_buff &that);
+    size_t       cur;
+    static TERM  none;
 
   protected:
-    DS_buff() : current(0) {}
-    DS_buff(const Size &lengths_, const Size &sizes_)
-    : data(lengths_,sizes_), current(0) {}
-    virtual ~DS_buff();
-
-    void           import(TC *in_, TC *des_out_);
-    virtual bool   do_resize(const Size &sizes_);
-    virtual bool   do_set_length(const Size &len_);
-    virtual bool   do_reset();
-    virtual void   do_next();
-    virtual bool   do_seek(size_t term_pos_);
-    virtual bool   do_locate(const Loc &loc_);
+    DS_buff() : data(0), cur(0) {}
+    
+    void           rebuild(DS &that);
+    void           rebuild(const Term &data_);
+    void           rebuild(TS &data_);
+    void           rebuild(TS *data_) { rebuild(*data_); }
+    virtual bool   resize(const Size &sizes_);
+    virtual bool   set_length(const Size &length_);
+    virtual bool   set_limits(const Size &length_, const Size &sizes_);
     virtual TS    *all_terms();
-    inline bool    des_resize(const Size &sizes_);
 
+    DS_buff &operator = (DS &that) { rebuild(that); return *this; }
+    DS_buff &operator = (const Term &data_) { rebuild(data_); return *this; }
+    DS_buff &operator = (TS &data_) { rebuild(data_); return *this; }
+    
   public:
-    DS_buff(TC &in_, TC &des_out_)
-    : current(size_max) { import(&in_,&des_out_); }
-    DS_buff(TC *in_, TC *des_out_)
-    : current(size_max) { import(in_,des_out_); }
+    DS_buff(DS &that) : data(0), cur(0) { rebuild(that); }
+    DS_buff(const DS_buff &that)
+    : data(that.data ? new TS(*that.data) : 0), lengths(that.lengths), cur(0)
+    { data->locate(current,0); lengths.next(loc); }
+    DS_buff(const Size &lengths_, const Size &sizes_)
+    : data(new TS(lengths_,sizes_)), lengths(lengths_), cur(0)
+    { data->locate(current,0); lengths.next(loc); }
+    DS_buff(const Term &data_)  : data(0), cur(0) { rebuild(data_); }
+    DS_buff(TS &data_) : data(0), cur(0) { rebuild(data_); }
+    DS_buff(TS *data_) : data(0), cur(0) { rebuild(data_); }
+    virtual ~DS_buff();
     
     virtual const Size &get_lengths() const;
     virtual size_t      get_length() const;
     virtual const Size &get_sizes() const; /* term sizes */
     virtual size_t      get_size() const;  /* returns overall term size */
+    virtual bool        reset();
+    virtual void        feed();
+    virtual bool        seek(size_t term_pos_);
+    virtual bool        locate(const Loc &loc_);
     virtual Term       &term();
     virtual const Term &term() const;
     virtual const Loc  &where() const;
     virtual size_t      which() const;
     virtual const TS   *all_terms() const;
-
  };
 
-  //                   //
- // class DS_buff_des //
-//                   //
-
-  class DS_buff_des : public DS_buff, public DS_des
-  {
-  public:
-    DS_buff_des(DS &in_)
-    : DS(this), DS_buff(), DS_des(in_) {}
-    DS_buff_des(DS &in_, const Size &sizes_)
-    : DS(this), DS_buff(in_.get_lengths(),sizes_), DS_des(in_) {}
-    virtual ~DS_buff_des();
-
-    virtual const Size &get_lengths() const;
-    virtual size_t      get_length() const;
-    virtual const Loc  &where() const;
-    virtual size_t      which() const;
-  };
-
 } // namespace ANN
 
-bool
-ANN::DS_buff::des_resize(const Size &sizes_)
-{
-  if (des_out) return ANN::DS_buff::des_resize(sizes_);
-  des_out=new DS_buff_des(*this,sizes_);
-  return true;
-}
-
 #endif /* __ANN_DS_BUFF_H */
