@@ -37,17 +37,11 @@ namespace ANN
   {
   private:
     NE   *elem;
-    Term  out_data;
+    TERM  out_data;
 
     DS_out();
     DS_out(const DS_out &that);
 
-  protected:
-    virtual bool        do_reset();
-    virtual void        do_next();
-    virtual bool        do_seek(size_t term_);
-    virtual bool        do_locate(const Loc &loc);
-
   public:
     virtual bool        act_on(NE *elem_);
 
@@ -60,6 +54,10 @@ namespace ANN
     virtual size_t      get_size() const;
     virtual Term       &term();
     virtual const Term &term() const;
+    virtual bool        reset();
+    virtual void        feed();
+    virtual bool        seek(size_t term_);
+    virtual bool        locate(const Loc &loc);
   };
 
 } // namespace ANN
