@@ -26,8 +26,7 @@
 namespace ANN
 {
 
-  class DS_rec;     /* recurent data source */
-  class DS_rec_des; /* recurent data source for desired output */
+  class DS_rec; /* recurent data source */
 
   //              //
  // class DS_rec //
@@ -41,12 +40,7 @@ namespace ANN
   protected:
     DS *orig;
 
-    DS_rec(DS &orig_, bool mk_des=true);
-
-    virtual bool  do_reset();
-    virtual void  do_next();
-    virtual bool  do_seek(size_t term_pos_);
-    virtual bool  do_locate(const Loc &loc);
+    DS_rec(DS &orig_) : orig(&orig_) {}
 
   public:
     virtual ~DS_rec();
@@ -57,33 +51,10 @@ namespace ANN
     virtual size_t      get_size() const;
     virtual Term       &term();
     virtual const Term &term() const;
-    virtual const Loc  &where() const;
-    virtual size_t      which() const;
-  };
-
-  //                  //
- // class DS_rec_des //
-//                  //
-
-  class DS_rec_des : public DS_rec, public DS_des
-  {
-  private:
-    DS_rec_des();
-    DS_rec_des(const DS_rec_des &that);
-
-  protected:
-    virtual bool  do_reset();
-    virtual void  do_next();
-    virtual bool  do_seek(size_t term_pos_);
-    virtual bool  do_locate(const Loc &loc);
-
-  public:
-    DS_rec_des(DS &in_, DS &orig_)
-    : DS(this), DS_rec(orig_,false), DS_des(in_) {}
-    ~DS_rec_des();
-
-    virtual const Size &get_lengths() const;
-    virtual size_t      get_length() const;
+    virtual bool        reset();
+    virtual void        feed();
+    virtual bool        seek(size_t term_pos_);
+    virtual bool        locate(const Loc &loc);
     virtual const Loc  &where() const;
     virtual size_t      which() const;
   };
