@@ -40,15 +40,14 @@ namespace ANN
     size_t  perm_len;
     size_t  current;
 
-    virtual bool  do_reset();
-    virtual void  do_next();
-    virtual bool  do_seek(size_t term_pos_);
-    virtual bool  do_locate(const Loc &loc);
-
   public:
-    DS_rnd(DS &orig_, bool mk_des=true);
+    DS_rnd(DS &orig_);
     virtual ~DS_rnd();
     
+    virtual bool   reset();
+    virtual void   feed();
+    virtual bool   seek(size_t term_pos_);
+    virtual bool   locate(const Loc &loc);
     virtual size_t which() const;
   };
   
