@@ -44,11 +44,17 @@ namespace ANN
     }              pos;
     size_t         cap;
 
-    static size_t get_dim(const size_t *coordinates_);
-    void          resize(size_t dimension_, const size_t *coordinates_,
+    static size_t  get_dim(const size_t *coordinates_);
+    void           resize(size_t dimension_, const size_t *coordinates_,
                          size_t value);
+    const size_t  *coord() const
+    { return cap ? pos.coordinates : (dimension==1 ? &pos.coordinate : 0); }
+    size_t        *coord()
+    { return cap ? pos.coordinates : (dimension==1 ? &pos.coordinate : 0); }
     
   public:
+    static const Loc empty;
+  
     void          resize(size_t dimension_, const size_t *coordinates_)
     { resize(dimension_,coordinates_,0); }
     void          resize(size_t dimension_, size_t value=0)
@@ -74,10 +80,8 @@ namespace ANN
     ~Loc();
 
     size_t        dim() const { return dimension; }
-    const size_t *coord() const
-    { return cap ? pos.coordinates : (dimension==1 ? &pos.coordinate : 0); }
-    size_t       *coord()
-    { return cap ? pos.coordinates : (dimension==1 ? &pos.coordinate : 0); }
+    const size_t *get_coord() const { return coord(); }
+    size_t       *get_coord() { return coord(); }
     size_t        product() const; /* multiplication of all coordinates */
     Loc          &expand(const Loc &that);
     /* expands each coords, so each of them is max of its previous value and
@@ -117,9 +121,10 @@ namespace ANN
   protected:
     size_t total;
     
-    size_t *coord() { return Loc::coord(); }    
-    void    resize(size_t dimension_, const size_t *coordinates_,
-                   size_t value);
+    size_t       *coord() { return Loc::coord(); }    
+    const size_t *coord() const { return Loc::coord(); }
+    void          resize(size_t dimension_, const size_t *coordinates_,
+                         size_t value);
     
   public:
     void    resize(size_t dimension_, const size_t *coordinates_)
@@ -129,7 +134,7 @@ namespace ANN
     void    resize(size_t total_) { Loc::resize(1,&total_,0); total=total_; }
     void    resize(const size_t *coordinates_=0) 
     { resize(get_dim(coordinates_),coordinates_,0); }
-    void    resize(const Loc &that) { resize(that.dim(),that.coord(),0); }
+    void    resize(const Loc &that) { resize(that.dim(),that.get_coord(),0); }
     void    resize(const Size &that)
     { Loc::resize(that.dimension,that.coord(),0); total=that.total; }
           
@@ -146,7 +151,7 @@ namespace ANN
     ~Size() {}
 
     size_t        dim() const { return dimension; }
-    const size_t *coord() const { return Loc::coord(); }
+    const size_t *get_coord() const { return Loc::coord(); }
     size_t        total_size() const { return total; }
     Size         &expand(const Loc &that);
     Size         &expand(const Size &that);
@@ -179,7 +184,7 @@ namespace ANN
 inline void 
 ANN::Loc::resize(const Size &that)
 { 
-  resize(that.dim(),that.coord(),0);
+  resize(that.dim(),that.get_coord(),0);
 }
 
 #endif /* __ANN_LOC_H */
