@@ -63,17 +63,17 @@ namespace ANN
     virtual bool    detach(Log_rec &child);
     virtual bool    is_active() const;
     /* tells whether logging is possible */
-    virtual void    reset(const char *label_=0);
+    virtual void    commence(const char *label_=0);
     /* restarts logging */
-    virtual void    prepare(size_t epoch);
+    virtual void    open(size_t epoch);
     /* caled whenever epoch starts */
-    virtual void    stepped(size_t which_, const Loc *where_);
+    virtual void    feed(size_t which_, const Loc *where_);
     /* caled whenever step starts */
-    virtual void    update(size_t epoch);
+    virtual void    close(size_t epoch);
     /* caled whenever epoch ends */
-    virtual void    finish(size_t epoch);
+    virtual void    conclude(size_t epoch);
     /* caled whenever teaching finishes */
-    virtual void    finished(size_t epoch);
+    virtual void    concluded(size_t epoch);
     /* caled whenever teaching is finished */
     virtual Log    &flush()=0;
     /* synchronizes buffers with storage */
@@ -126,12 +126,12 @@ namespace ANN
     virtual void log_size(const Size &l);
     virtual void log_term(const Term &t, const char *label, size_t which,
                           const Loc *where);
-    virtual void prop_reset();
-    virtual void prop_prepare(size_t epoch);
-    virtual void prop_stepped(size_t which_, const Loc *where_);
-    virtual void prop_update(size_t epoch);
-    virtual void prop_finish(size_t epoch);
-    virtual void prop_finished(size_t epoch);
+    virtual void prop_commence();
+    virtual void prop_open(size_t epoch);
+    virtual void prop_feed(size_t which_, const Loc *where_);
+    virtual void prop_close(size_t epoch);
+    virtual void prop_conclude(size_t epoch);
+    virtual void prop_concluded(size_t epoch);
 
   public:
     Log_rec(Log &orig_) : orig(&orig_), active(false) { orig->attach(*this); }
@@ -143,12 +143,12 @@ namespace ANN
     virtual char    get_sublevel_end() const;
     virtual size_t  get_margin() const;
     virtual bool    is_active() const;
-    virtual void    reset(const char *label_=0);
-    virtual void    prepare(size_t epoch);
-    virtual void    stepped(size_t which_, const Loc *where_);
-    virtual void    update(size_t epoch);
-    virtual void    finish(size_t epoch);
-    virtual void    finished(size_t epoch);
+    virtual void    commence(const char *label_=0);
+    virtual void    open(size_t epoch);
+    virtual void    feed(size_t which_, const Loc *where_);
+    virtual void    close(size_t epoch);
+    virtual void    conclude(size_t epoch);
+    virtual void    concluded(size_t epoch);
     virtual Log    &flush();
 
     friend class LS;
@@ -163,16 +163,15 @@ namespace ANN
   protected:
     LS() {}
 
-    void prop_reset(Log_rec &log) { log.prop_reset(); }
-    void prop_prepare(Log_rec &log, size_t epoch) { log.prop_prepare(epoch); }
-    void prop_stepped(Log_rec &log, size_t which_, const Loc *where_)
-    { log.prop_stepped(which_,where_); }
-    void prop_update(Log_rec &log, size_t epoch)
-    { log.prop_update(epoch); }
-    void prop_finish(Log_rec &log, size_t epoch)
-    { log.prop_finish(epoch); }
-    void prop_finished(Log_rec &log, size_t epoch)
-    { log.prop_finished(epoch); }
+    void prop_commence(Log_rec &log) { log.prop_commence(); }
+    void prop_open(Log_rec &log, size_t epoch) { log.prop_open(epoch); }
+    void prop_feed(Log_rec &log, size_t which_, const Loc *where_)
+    { log.prop_feed(which_,where_); }
+    void prop_close(Log_rec &log, size_t epoch) { log.prop_close(epoch); }
+    void prop_conclude(Log_rec &log, size_t epoch)
+    { log.prop_conclude(epoch); }
+    void prop_concluded(Log_rec &log, size_t epoch)
+    { log.prop_concluded(epoch); }
 
   public:
     virtual ~LS();
@@ -180,12 +179,12 @@ namespace ANN
 
     virtual bool  attach(Log_rec &child)=0;
     virtual bool  detach(Log_rec &child)=0;
-    virtual void  reset()=0;
-    virtual void  prepare(size_t epoch)=0;
-    virtual void  stepped(size_t which_, const Loc *where_)=0;
-    virtual void  update(size_t epoch)=0;
-    virtual void  finish(size_t epoch)=0;
-    virtual void  finished(size_t epoch)=0;
+    virtual void  commence()=0;
+    virtual void  open(size_t epoch)=0;
+    virtual void  feed(size_t which_, const Loc *where_)=0;
+    virtual void  close(size_t epoch)=0;
+    virtual void  conclude(size_t epoch)=0;
+    virtual void  concluded(size_t epoch)=0;
   };
 
 } // namespace ANN
