@@ -69,12 +69,12 @@ namespace ANN
     virtual char    get_sublevel_beg() const;
     virtual char    get_sublevel_end() const;
     virtual size_t  get_margin() const;
-    virtual void    reset(const char *label_=0);
-    virtual void    prepare(size_t epoch_);
-    virtual void    stepped(size_t which_, const Loc *where_);
-    virtual void    update(size_t epoch_);
-    virtual void    finish(size_t epoch_);
-    virtual void    finished(size_t epoch_);
+    virtual void    commence(const char *label_=0);
+    virtual void    open(size_t epoch_);
+    virtual void    feed(size_t which_, const Loc *where_);
+    virtual void    close(size_t epoch_);
+    virtual void    conclude(size_t epoch_);
+    virtual void    concluded(size_t epoch_);
     virtual Log    &flush();
   };
 
