@@ -46,12 +46,12 @@ namespace ANN
 
     virtual bool  attach(Log_rec &child);
     virtual bool  detach(Log_rec &child);
-    virtual void  reset();
-    virtual void  prepare(size_t epoch);
-    virtual void  stepped(size_t which_, const Loc *where_);
-    virtual void  update(size_t epoch);
-    virtual void  finish(size_t epoch);
-    virtual void  finished(size_t epoch);
+    virtual void  commence();
+    virtual void  open(size_t epoch);
+    virtual void  feed(size_t which_, const Loc *where_);
+    virtual void  close(size_t epoch);
+    virtual void  conclude(size_t epoch);
+    virtual void  concluded(size_t epoch);
   };
 
 } // namespace ANN
