@@ -23,17 +23,16 @@
 #include <ann_loc.h>
 #include <ann_init.h>
 #include <ann_term.h>
-#include <ann_ds.h>
 #include <ann_factory.h>
+#include <ann_parser_log.h>
 
 namespace ANN
 {
   class NE;
 }
 
-#include <ann_weight.h>
-#include <ann_to.h>
 #include <ann_log.h>
+#include <ann_weight.h>
 
 namespace ANN
 {
@@ -48,6 +47,15 @@ namespace ANN
     typedef Log         Common_t;
     typedef const Init *Instance_t;
     typedef NE          Base_t;
+    
+    enum Status
+    {
+      done,    // training or computations successfully completed
+      wrong,   // training or computations impossible using provided data
+      not_yet, // training not completed yet, but some progress possible
+      never,   // not trained but cannot help it
+      dumb     // no information about training progress avalable
+    };
 
   private:
     NE();
@@ -58,9 +66,10 @@ namespace ANN
     Size               in_size;
     Log               *log;
     static const Size  single_out_size;
-
-    NE(Size in_size_, Log *log_=0, const char *label_=0);
-    NE(Size in_size_, const char *label_);
+    
+    NE(Size in_size_, Log &log_, const char *label_=0);
+    NE(Size in_size_, Log *log_, const char *label_=0);
+    NE(Size in_size_, const char *label_=0);
     NE(Log &log_, Instance_t inst)
     : label(inst->dup_label()), in_size(inst->size), log(&log_) {}
     NE(Log *log_, Instance_t inst)
@@ -72,34 +81,38 @@ namespace ANN
     virtual ~NE();
 
     const Size           &get_in_sizes() const { return in_size; }
-    const size_t          get_in_size() const { return in_size.total_size(); }
+    size_t                get_in_size() const { return in_size.total_size(); }
     virtual const Size   &get_out_sizes() const;
-    virtual const size_t  get_out_size() const;
-    virtual void          calc(const Term &in, Term &out)=0;
-    
-    /* Low level adaptation routines */
-    virtual bool          is_supervised() const=0;
-    /* tells whether adapt() method requires out_bp */
-    virtual void          reset(TO &t, bool b_reload=false)=0;
-    /* element moves its state to the very begining of adaptation */
-    virtual void          prepare(TO &t);
-    /* called every time epoch starts */
-    virtual int           update(TO &t);
-    /* called every time epoch ends, returns 1 if the element need no more
-     * training, -1 if the element need more trainig and 0 it the element
-     * cannot asses */
-    virtual void          finish(TO &t);
-    /* called when training is finished */
-    virtual void          adapt(const Term &in, const Term &out,
-                                const Term *out_bp, Term *in_bp)=0;
-    /* called after each presentation, should backpropagate errors (if needed)
-     * and calculate weights' partial changes/gradients */
+    virtual size_t        get_out_size() const;
+
+    /** output comutation **/
+    virtual Status        feed(const Term &in, Term &out)=0;
+
+    /** before training starts or after it stops **/
+    virtual void          reset(bool prod=false);
+    /* switch between training and production modes */
     virtual bool          load(Parser_log &parser, time_t begin=0,
-                               time_t end=NAV_get(time_t)); 
-    virtual void          store(Log &log_);                  
+                               time_t end=NAV_get(time_t));
+    /* loads state information from a log, you should call reset() then */
+    virtual void          store(Log &log_);
+    /* stores state information to a log */
+    virtual void          randomize();
+    /* randomizes weights */
+
+    /** trainig **/
+    virtual Status        adapt_for(size_t epochs=1)=0;
+    /* conducts training for no more than specified number of epochs */
+    virtual size_t        get_epoch() const=0;
+    /* reports current epoch */
   };
 
   typedef FB<NE,const Init *> NE_FB;
+
+  NE::Status operator + (NE::Status s1, NE::Status s2);
+  inline NE::Status operator + (NE::Status s1, bool s2)
+  { return s1 + (s2 ? NE::done : NE::not_yet); }
+  inline NE::Status operator - (NE::Status s1, bool s2)
+  { return s1 + (s2 ? NE::never : NE::not_yet); }
   
 } //namespace ANN
 
