@@ -29,7 +29,8 @@ namespace ANN
     static double get() { return NAN; }
   };
 
-  typedef Array<double> Term; /* training set term */
+  typedef Array<double> Term; /* training set term (weak container) */
+  typedef ARRAY<double> TERM; /* training set term (strong container) */
   
 } // namespace ANN
 
