@@ -49,7 +49,7 @@ namespace ANN
     W_delta(const W_delta &);
 
   protected:
-    Term d;
+    TERM d;
 
   public:
     typedef WC<WG_delta>  Common_t;
@@ -60,9 +60,9 @@ namespace ANN
     W_delta(Common_t &c, Instance_t inst) : W(inst), d(inst->size) {}
     virtual ~W_delta();
 
-    virtual void      prepare(TO &t);
-    virtual void      adapt(const Term &d_);
-    virtual void      update(TO &t);
+    virtual void      commence(NE &ne);
+    virtual void      feed_back(const Term &d_);
+    virtual void      commit(NE &ne);
     virtual WG_delta &the_group() const=0;
   };
 
