@@ -88,8 +88,8 @@ namespace ANN
     W_mntm(const W_mntm &);
 
   protected:
-    Term d;
-    Term delta;
+    TERM d;
+    TERM delta;
 
   public:
     typedef WC<WG_mntm>   Common_t;
@@ -101,10 +101,10 @@ namespace ANN
     : W(inst), d(inst->size), delta(inst->size) {}
     virtual ~W_mntm();
 
-    virtual void     reset(TO &t);
-    virtual void     prepare(TO &t);
-    virtual void     adapt(const Term &d_);
-    virtual void     update(TO &t);
+    virtual void     reset(NE *ne);
+    virtual void     commence(NE &ne);
+    virtual void     feed_back(const Term &d_);
+    virtual void     commit(NE &ne);
     virtual WG_mntm &the_group() const=0;
   };
 
