@@ -83,7 +83,7 @@ namespace ANN
     W_step(const W_step &);
 
   protected:
-    Term d;
+    TERM d;
 
   public:
     typedef WC<WG_step>   Common_t;
@@ -94,9 +94,9 @@ namespace ANN
     W_step(Common_t &c, Instance_t inst) : W(inst), d(inst->size) {}
     virtual ~W_step();
 
-    virtual void     prepare(TO &t);
-    virtual void     adapt(const Term &d_);
-    virtual void     update(TO &t);
+    virtual void     commence(NE &ne);
+    virtual void     feed_back(const Term &d_);
+    virtual void     commit(NE &ne);
     virtual WG_step &the_group() const=0;
   };
 
