@@ -35,7 +35,7 @@ namespace ANN
 #include <ann_term.h>
 #include <ann_log.h>
 #include <ann_parser_log.h>
-#include <ann_to.h>
+#include <ann_ne.h>
 #include <ann_factory.h>
 
 namespace ANN
@@ -53,7 +53,7 @@ namespace ANN
     
   protected:
     char *label;
-    Term  w;
+    TERM  w;
 
   public:
     typedef void        Common_t;
@@ -70,21 +70,21 @@ namespace ANN
     const char   *get_label() const { return label; }
     virtual bool  has_label(const char *label_);
     virtual WG   *get_group() const;
-    virtual void  reset(TO &t);            /* resets weight before training */
-    virtual void  prepare(TO &t);          /* prepares to an epoch */
-    virtual void  adapt(const Term &d_)=0; /* called during training */
-    virtual void  update(TO &t)=0;         /* updates value */
-    virtual void  finish(TO &t);           /* training ends */
-    virtual void  randomize();             /* randomizes value */
+    virtual void  reset(NE *ne);                           /* mode switches */
+    virtual void  commence(NE &ne);            /* training period commences */
+    virtual void  feed_back(const Term &d_)=0;    /* called during training */
+    virtual void  commit(NE &ne)=0;                        /* updates value */
+    virtual void  conclude(NE &ne);            /* training period concludes */
+    virtual void  randomize();                          /* randomizes value */
     virtual bool  load(Parser_log &parser, time_t begin=0,
                        time_t end=NAV_get(time_t)); /* loads from a log */
     virtual void  store(Log &log);                  /* stores to a log */
-    static void   drop_weights(Array<W *> &wa);
   };
 
-  typedef FB<W,const Init *> W_FB;
-  typedef Array<W *>         WA;
-  
+  typedef FB<W,const Init *>                W_FB;
+  typedef Array<W *,W *,Manip_ptr_take<W> > Wa;
+  typedef ARRAY<W *,W *,Manip_ptr_take<W> > WA;
+
   //           //
  // class WGC //
 //           //
@@ -115,7 +115,7 @@ namespace ANN
     typedef Log           Common_t;
     typedef W::Instance_t Instance_t;
     typedef WG            Base_t;
-    
+
   private:
     WG(WG &that);
 
@@ -131,18 +131,19 @@ namespace ANN
     virtual bool signature_find(Parser_log &parser, time_t begin=0,
                                 time_t end=NAV_get(time_t));
     virtual void signature_write(Log &log, W &w);
-    
+
   public:
     virtual ~WG();
 
     virtual bool   has_label(const char *label_)=0;
-    virtual void   reset(TO &t);
-    virtual void   prepare(TO &t);
-    virtual void   prepared(TO &t);
-    virtual void   update(TO &t);
-    virtual void   updated(TO &t);
-    virtual void   finish(TO &t);   
-    virtual void   finished(TO &t); 
+    virtual void   reset(NE *ne);
+    virtual void   reseted(NE *ne);
+    virtual void   commence(NE &ne);
+    virtual void   commenced(NE &ne);
+    virtual void   commit(NE &ne);
+    virtual void   commited(NE &ne);
+    virtual void   conclude(NE &ne);
+    virtual void   concluded(NE &ne);
     virtual double get_random();
     static double  def_random();
     virtual bool   load(Parser_log &parser, time_t begin=0,
@@ -166,17 +167,17 @@ namespace ANN
   public:
     virtual ~WS();
     static WS *create();
-    
+
     virtual void register_weight(W &w)=0;
     virtual void erase_weights()=0;
-    virtual void reset(TO &t)=0;   /* resets weights before training */
-    virtual void prepare(TO &t)=0; /* prepares to an epoch */
-    virtual void update(TO &t)=0;  /* updates value */
-    virtual void finish(TO &t)=0;  /* training ends */
-    virtual void randomize()=0;    /* randomizes value */
+    virtual void reset(NE *ne)=0;
+    virtual void commence(NE &ne)=0;
+    virtual void commit(NE &ne)=0;  
+    virtual void conclude(NE &ne)=0;  
+    virtual void randomize()=0;    
     virtual bool load(Parser_log &parser, time_t begin=0,
-                      time_t end=NAV_get(time_t))=0; /* loads from a log */
-    virtual void store(Log &log)=0;                  /* stores to a log */
+                      time_t end=NAV_get(time_t))=0; 
+    virtual void store(Log &log)=0;                  
   };
 
 } // namespace ANN
