@@ -17,19 +17,19 @@
 
 #include <ann_cybenko.h>
 
-ANN::NE_mlayer *
+ANN::NFB_mlayer *
 ANN::create_Cybenko(Log *log, const char *label, size_t in, size_t hidden,
                     size_t out, W_FB &w, Act &act, bool bias)
 {
   Init inst(in,label ? label : "Cybenko_net");
-  NEC_perc hid_par(hidden,log,&w,act,bias);
-  NEC_perc out_par(out,log,&w,Act::linear,bias);
-  NE_perc_F *factory[]=
+  NFBC_perc hid_par(hidden,log,&w,act,bias);
+  NFBC_perc out_par(out,log,&w,Act::linear,bias);
+  NFB_perc_F *factory[]=
   {
-    new NE_perc_F(hid_par),
-    new NE_perc_F(out_par),
+    new NFB_perc_F(hid_par),
+    new NFB_perc_F(out_par),
   };
-  NE_mlayer *ret=new NE_mlayer(&inst,log,factory,factory+2);
-  NE_mlayer::drop_f(factory,factory+2);
+  NFB_mlayer *ret=new NFB_mlayer(&inst,log,factory,factory+2);
+  NFB_mlayer::drop_f(factory,factory+2);
   return ret;
 }
