@@ -26,37 +26,17 @@ ANN::DS_out::~DS_out()
 }
 
 bool
-ANN::DS_out::do_reset()
+ANN::DS_out::act_on(NE *elem_)
 {
-  bool ret=(elem && ANN::DS_rec::do_reset());
-  if (ret) elem->calc(orig->term(),out_data);
-  return ret;
-}
-
-void
-ANN::DS_out::do_next()
-{
-  if (elem)
+  if (elem_)
   {
-    ANN::DS_rec::do_next();
-    elem->calc(orig->term(),out_data);
+    size_t l=elem_->get_in_size();
+    if (!l || (l!=orig->get_size())) return false;
+    out_data.resize(elem_->get_out_sizes());
   }
-}
-
-bool
-ANN::DS_out::do_seek(size_t term_)
-{
-  bool ret=(elem && ANN::DS_rec::do_seek(term_));
-  if (ret) elem->calc(orig->term(),out_data);
-  return ret;
-}
-
-bool
-ANN::DS_out::do_locate(const Loc &loc)
-{
-  bool ret=(elem && ANN::DS_rec::do_locate(loc));
-  if (ret) elem->calc(orig->term(),out_data);
-  return ret;
+  else out_data.resize(Size());
+  elem=elem_;
+  return true;
 }
 
 const ANN::Size &
@@ -84,16 +64,36 @@ ANN::DS_out::term() const
 }
 
 bool
-ANN::DS_out::act_on(NE *elem_)
+ANN::DS_out::reset()
 {
-  if (elem_)
+  bool ret=(elem && ANN::DS_rec::reset());
+  if (ret) elem->feed(orig->term(),out_data);
+  return ret;
+}
+
+void
+ANN::DS_out::feed()
+{
+  if (elem)
   {
-    size_t l=elem_->get_in_size();
-    if (!l || (l!=orig->get_size())) return false;
-    out_data.resize(elem_->get_out_sizes());
+    ANN::DS_rec::feed();
+    elem->feed(orig->term(),out_data);
   }
-  else out_data.resize(Size());
-  elem=elem_;
-  return true;
+}
+
+bool
+ANN::DS_out::seek(size_t term_)
+{
+  bool ret=(elem && ANN::DS_rec::seek(term_));
+  if (ret) elem->feed(orig->term(),out_data);
+  return ret;
+}
+
+bool
+ANN::DS_out::locate(const Loc &loc)
+{
+  bool ret=(elem && ANN::DS_rec::locate(loc));
+  if (ret) elem->feed(orig->term(),out_data);
+  return ret;
 }
 
