@@ -21,44 +21,10 @@
  // class ANN::DS_rec //
 //                   //
 
-ANN::DS_rec::DS_rec(DS &orig_, bool mk_des)
-: orig(&orig_)
-{
-  if (mk_des)
-  {
-    DS *des=orig->des_output();
-    if (des) des_out=new DS_rec_des(*this,*des);
-  }
-}
-
 ANN::DS_rec::~DS_rec()
 {
 }
 
-bool
-ANN::DS_rec::do_reset()
-{
-  return orig->reset();
-}
-
-void
-ANN::DS_rec::do_next()
-{
-  orig->next();
-}
-
-bool
-ANN::DS_rec::do_seek(size_t term_pos_)
-{
-  return orig->seek(term_pos_);
-}
-
-bool
-ANN::DS_rec::do_locate(const Loc &loc)
-{
-  return orig->locate(loc);
-}
-
 const ANN::Size &
 ANN::DS_rec::get_lengths() const
 {
@@ -95,6 +61,30 @@ ANN::DS_rec::term() const
   return orig->term();
 }
 
+bool
+ANN::DS_rec::reset()
+{
+  return orig->reset();
+}
+
+void
+ANN::DS_rec::feed()
+{
+  orig->feed();
+}
+
+bool
+ANN::DS_rec::seek(size_t term_pos_)
+{
+  return orig->seek(term_pos_);
+}
+
+bool
+ANN::DS_rec::locate(const Loc &loc)
+{
+  return orig->locate(loc);
+}
+
 const ANN::Loc &
 ANN::DS_rec::where() const
 {
@@ -107,58 +97,3 @@ ANN::DS_rec::which() const
   return orig->which();
 }
 
-  //                       //
- // class ANN::DS_rec_des //
-//                       //
-
-ANN::DS_rec_des::~DS_rec_des()
-{
-}
-
-bool
-ANN::DS_rec_des::do_reset()
-{
-  return false;
-}
-
-void
-ANN::DS_rec_des::do_next()
-{
-}
-
-bool
-ANN::DS_rec_des::do_seek(size_t term_pos_)
-{
-  return false;
-}
-
-bool
-ANN::DS_rec_des::do_locate(const Loc &loc)
-{
-  return false;
-}
-
-const ANN::Size &
-ANN::DS_rec_des::get_lengths() const
-{
-  return orig->get_lengths();
-}
-
-size_t
-ANN::DS_rec_des::get_length() const
-{
-  return orig->get_length();
-}
-
-const ANN::Loc &
-ANN::DS_rec_des::where() const
-{
-  return in->where();
-}
-
-size_t
-ANN::DS_rec_des::which() const
-{
-  return in->which();
-}
-
