@@ -45,8 +45,8 @@ randomize_arr(size_t *arr, size_t *arr_, size_t len)
   }  
 }
 
-ANN::DS_rnd::DS_rnd(DS &orig_, bool mk_des)
-: DS_rec(orig_,mk_des), perm(0), perm_len(orig_.get_length()), current(0)
+ANN::DS_rnd::DS_rnd(DS &orig_)
+: DS_rec(orig_), perm(0), perm_len(orig_.get_length()), current(0)
 {
   if (perm_len!=size_max)
   {
@@ -63,34 +63,41 @@ ANN::DS_rnd::~DS_rnd()
 }
 
 bool
-ANN::DS_rnd::do_reset()
+ANN::DS_rnd::reset()
 {
-  if (!orig->reset()) return false;
-  randomize_arr(perm,perm_,perm_len);
-  return orig->seek(perm[current=0]);
+  bool ret=false;
+  if (orig->reset() && (perm_len!=size_max))
+  {
+    randomize_arr(perm,perm_,perm_len);
+    if (orig->seek(perm[current=0])) ret=true;
+  }
+  if (!ret) orig->feed();
+  return ret;
 }
 
 void
-ANN::DS_rnd::do_next()
+ANN::DS_rnd::feed()
 {
-  if (perm_len==size_max) orig->next();
-  if (++current>=perm_len) current=0;
-  if (!(orig->seek(perm[current]))) orig->next();
+  bool ok;
+  if (ok=(perm_len!=size_max))
+    if (current<perm_len) ++current; else current=0;
+  if (!ok || !(orig->seek(perm[current]))) orig->feed();
 }
 
 bool
-ANN::DS_rnd::do_seek(size_t term_pos_)
+ANN::DS_rnd::seek(size_t term_pos_)
 {
   return (perm_len!=size_max)
-    && orig->seek((current=term_pos_)<perm_len ? perm[term_pos_] : term_pos_);
+          && orig->seek((current=term_pos_)<perm_len
+                        ? perm[term_pos_] : term_pos_);
 }
 
 bool
-ANN::DS_rnd::do_locate(const Loc &loc)
+ANN::DS_rnd::locate(const Loc &loc)
 {
   if (!orig->locate(loc)) return false;
   current=orig->which();
-  if (current<perm_len) current=perm_[current];
+  if ((perm_len!=size_max) && (current<perm_len)) current=perm_[current];
   return true;
 }
 
