@@ -25,59 +25,55 @@
  // class DS_tee //
 //              //
 
-ANN::DS_tee::DS_tee(DS &orig_, Sink &sink_, const char *label_in_,
-                    const char *label_des_out_)
-: DS_rec(orig_), sink(&sink_), label_in(Init::dup_str(label_in_)),
-  label_des_out(Init::dup_str(label_des_out_)), active(false)
+ANN::DS_tee::DS_tee(DS &orig_, Sink &sink_, const char *label_)
+: DS_rec(orig_), sink(&sink_), label(Init::dup_str(label_)), active(false)
 {  
 }
 
 ANN::DS_tee::~DS_tee()
 {
-  if (active) sink->update();
-  if (label_in) delete [] label_in;
-  if (label_des_out) delete [] label_des_out;
+  if (active) sink->close();
+  if (label) delete [] label;
 }
 
-void ANN::DS_tee::log_term()
+void ANN::DS_tee::store_term()
 {
   if (active && (last!=where()))
   {
-    active=sink->feed(which(),last=where(),input()->term(),
-                      des_output() ? &des_output()->term() : 0);
-    if (!active) sink->update();                  
+    active=sink->feed(which(),last=where(),term(),label);
+    if (!active) sink->close();
   }
 }
 
 bool
-ANN::DS_tee::do_reset()
+ANN::DS_tee::reset()
 {
-  if (active) sink->update();
-  bool ret=DS_rec::do_reset();
-  active=sink->prepare(get_lengths(),get_sizes(),label_in,label_des_out);
-  if (ret) log_term();
+  if (active) sink->close();
+  bool ret=DS_rec::reset();
+  active=sink->open(get_lengths(),get_sizes());
+  store_term();
   return ret;
 }
 
 void
-ANN::DS_tee::do_next()
+ANN::DS_tee::feed()
 {
-  ANN::DS_rec::do_next();
-  log_term();
+  ANN::DS_rec::feed();
+  store_term();
 }
 
 bool
-ANN::DS_tee::do_seek(size_t term_pos_)
+ANN::DS_tee::seek(size_t term_pos_)
 {
-  bool ret=ANN::DS_rec::do_seek(term_pos_);
-  if (ret) log_term();
+  bool ret=ANN::DS_rec::seek(term_pos_);
+  if (ret) store_term();
   return ret;
 }
 
 bool
-ANN::DS_tee::do_locate(const Loc &loc)
+ANN::DS_tee::locate(const Loc &loc)
 {
-  bool ret=ANN::DS_rec::do_locate(loc);
-  if (ret) log_term();
+  bool ret=ANN::DS_rec::locate(loc);
+  if (ret) store_term();
   return ret;
 }
