@@ -21,7 +21,8 @@
  // class ANN::Loc //
 //                //
 
-size_t ANN::Loc::nav=ANN::size_max;
+size_t         ANN::Loc::nav=ANN::size_max;
+const ANN::Loc ANN::Loc::empty;
 
 ANN::Loc::~Loc()
 {
@@ -178,7 +179,7 @@ ANN::Size &
 ANN::Size::expand(const Loc &that)
 {
   size_t        i, *coords, tmp;
-  const size_t *that_coords=that.coord();
+  const size_t *that_coords=that.get_coord();
   bool          b_set=(total && (total!=size_max));
   if (dimension<that.dim()) Loc::resize(that.dim(),0,total!=0);
   coords=coord();
@@ -271,7 +272,7 @@ ANN::Size::index(const Loc &loc) const
   size_t l_dim=loc.dim();
   if (l_dim>dimension) return size_max;
   size_t        i, idx=0, crdnt, limit;
-  const size_t *coords=coord(), *loc_coords=loc.coord();
+  const size_t *coords=coord(), *loc_coords=loc.get_coord();
   for (i=0; i<l_dim; ++i)
   {
     crdnt=loc_coords[i];
@@ -280,7 +281,7 @@ ANN::Size::index(const Loc &loc) const
     (idx*=limit)+=crdnt;
   }
   while (i<dimension)
-    if ((limit=coords[i])==size_max) return false; else idx*=coords[i++];
+    if ((limit=coords[i])==size_max) return size_max; else idx*=coords[i++];
   return idx;
 }
 
@@ -294,7 +295,7 @@ ANN::Size::next(Loc &loc) const
     return true;
   }  
   if (loc.dim()!=dimension) return false;
-  size_t        i=dimension, *loc_coords=loc.coord();
+  size_t        i=dimension, *loc_coords=loc.get_coord();
   const size_t *coords=coord();
   do
   {
@@ -312,7 +313,7 @@ ANN::Size::locate(size_t idx, Loc &loc) const
 {
   if (!total) return false;
   loc.resize(dimension);
-  size_t        i=dimension, *coords_=loc.coord();
+  size_t        i=dimension, *coords_=loc.get_coord();
   const size_t *coords=coord();
   while (i && idx)
   {
