@@ -98,39 +98,39 @@ ANN::Log::is_active() const
 }
 
 void
-ANN::Log::reset(const char *label_)
+ANN::Log::commence(const char *label_)
 {
-  if (children) children->reset();
+  if (children) children->commence();
 }
 
 void
-ANN::Log::prepare(size_t epoch)
+ANN::Log::open(size_t epoch)
 {
-  if (children) children->prepare(epoch);
+  if (children) children->open(epoch);
 }
 
 void
-ANN::Log::stepped(size_t which_, const Loc *where_)
+ANN::Log::feed(size_t which_, const Loc *where_)
 {
-  if (children) children->stepped(which_,where_);
+  if (children) children->feed(which_,where_);
 }
 
 void
-ANN::Log::update(size_t epoch)
+ANN::Log::close(size_t epoch)
 {
-  if (children) children->update(epoch);
+  if (children) children->close(epoch);
 }
 
 void
-ANN::Log::finish(size_t epoch)
+ANN::Log::conclude(size_t epoch)
 {
-  if (children) children->finish(epoch);
+  if (children) children->conclude(epoch);
 }
 
 void
-ANN::Log::finished(size_t epoch)
+ANN::Log::concluded(size_t epoch)
 {
-  if (children) children->finished(epoch);
+  if (children) children->concluded(epoch);
 }
 
   //                    //
@@ -198,39 +198,39 @@ ANN::Log_rec::log_term(const Term &t, const char *label, size_t which,
 }
 
 void
-ANN::Log_rec::prop_reset()
+ANN::Log_rec::prop_commence()
 {
-  if (children) children->reset();
+  if (children) children->commence();
 }
 
 void
-ANN::Log_rec::prop_prepare(size_t epoch)
+ANN::Log_rec::prop_open(size_t epoch)
 {
-  if (children) children->prepare(epoch);
+  if (children) children->open(epoch);
 }
 
 void
-ANN::Log_rec::prop_stepped(size_t which_, const Loc *where_)
+ANN::Log_rec::prop_feed(size_t which_, const Loc *where_)
 {
-  if (children) children->stepped(which_,where_);
+  if (children) children->feed(which_,where_);
 }
 
 void
-ANN::Log_rec::prop_update(size_t epoch)
+ANN::Log_rec::prop_close(size_t epoch)
 {
-  if (children) children->update(epoch);
+  if (children) children->close(epoch);
 }
 
 void
-ANN::Log_rec::prop_finish(size_t epoch)
+ANN::Log_rec::prop_conclude(size_t epoch)
 {
-  if (children) children->finish(epoch);
+  if (children) children->conclude(epoch);
 }
 
 void
-ANN::Log_rec::prop_finished(size_t epoch)
+ANN::Log_rec::prop_concluded(size_t epoch)
 {
-  if (children) children->finished(epoch);
+  if (children) children->concluded(epoch);
 }
 
 ANN::Time &
@@ -270,40 +270,40 @@ ANN::Log_rec::is_active() const
 }
 
 void
-ANN::Log_rec::reset(const char *label_)
+ANN::Log_rec::commence(const char *label_)
 {
   active=false;
-  orig->reset(label_);
+  orig->commence(label_);
 }
 
 void
-ANN::Log_rec::prepare(size_t epoch)
+ANN::Log_rec::open(size_t epoch)
 {
-  orig->prepare(epoch);
+  orig->open(epoch);
 }
 
 void
-ANN::Log_rec::stepped(size_t which_, const Loc *where_)
+ANN::Log_rec::feed(size_t which_, const Loc *where_)
 {
-  orig->stepped(which_,where_);
+  orig->feed(which_,where_);
 }
 
 void
-ANN::Log_rec::update(size_t epoch)
+ANN::Log_rec::close(size_t epoch)
 {
-  orig->update(epoch);
+  orig->close(epoch);
 }
 
 void
-ANN::Log_rec::finish(size_t epoch)
+ANN::Log_rec::conclude(size_t epoch)
 {
-  orig->finish(epoch);
+  orig->conclude(epoch);
 }
 
 void
-ANN::Log_rec::finished(size_t epoch)
+ANN::Log_rec::concluded(size_t epoch)
 {
-  orig->finished(epoch);
+  orig->concluded(epoch);
 }
 
 ANN::Log &
