@@ -65,7 +65,7 @@ ANN::Log_io::write_sep()
   if (ch_epoch)
   {
     ch_epoch=false;
-    nl(-marg,"epoch starts:");
+    nl(-marg,"epoch opens:");
     log_uint(epoch);
     nl(1,0);    
   }
@@ -168,32 +168,32 @@ ANN::Log_io::get_margin() const
 }
 
 void
-ANN::Log_io::reset(const char *label_)
+ANN::Log_io::commence(const char *label_)
 {
   step_which=epoch=size_max;
   ch_step=ch_epoch=false;
-  nl(-marg,"Reseting log");
+  nl(-marg,"Trainig commenced");
   if (label_)
   {
     log_str("for");
     log_str(label_);
   }
   nl(0,0);
-  Log::reset(label_);
+  Log::commence(label_);
 }
 
 void
-ANN::Log_io::prepare(size_t epoch_)
+ANN::Log_io::open(size_t epoch_)
 {
   epoch=epoch_;
   step_which=size_max;
   ch_epoch=true;
   ch_step=false;
-  Log::prepare(epoch_);
+  Log::open(epoch_);
 }
 
 void
-ANN::Log_io::stepped(size_t which_, const Loc *where_)
+ANN::Log_io::feed(size_t which_, const Loc *where_)
 {
   if (which_!=size_max)
   {
@@ -201,7 +201,7 @@ ANN::Log_io::stepped(size_t which_, const Loc *where_)
     step_which=which_;
     if (where_) step_where.resize(*where_); else step_where.resize();
   }  
-  Log::stepped(which_,where_);
+  Log::feed(which_,where_);
   if (which_==size_max)   
   {
     if ((step_which!=size_max) && !ch_step)
@@ -215,12 +215,12 @@ ANN::Log_io::stepped(size_t which_, const Loc *where_)
 }
 
 void
-ANN::Log_io::update(size_t epoch_)
+ANN::Log_io::close(size_t epoch_)
 {
-  Log::update(epoch_);
+  Log::close(epoch_);
   if ((epoch!=size_max) && !ch_epoch)
   {
-    nl(-marg,"epoch finished:");
+    nl(-marg,"epoch closed:");
     log_uint(epoch);
     nl(0,0);
   }
@@ -229,23 +229,24 @@ ANN::Log_io::update(size_t epoch_)
 }
 
 void
-ANN::Log_io::finish(size_t epoch_)
+ANN::Log_io::conclude(size_t epoch_)
 {
   epoch=step_which=size_max;
   ch_step=ch_epoch=false;
-  nl(-marg,"training reached epoch:");
+  nl(-marg,"training concludes on epoch:");
   log_uint(epoch_);
   nl(1,0);
-  Log::finish(epoch_);
+  Log::conclude(epoch_);
 }
 
 void
-ANN::Log_io::finished(size_t epoch_)
+ANN::Log_io::concluded(size_t epoch_)
 {
-  Log::finished(epoch_);
+  Log::concluded(epoch_);
   epoch=step_which=size_max;
   ch_step=ch_epoch=false;
-  nl(-marg,"training finished");
+  nl(-marg,"training concluded on epoch:");
+  log_uint(epoch_);
   nl(0,0);
 }
 
