@@ -56,49 +56,49 @@ ANN::LS_set::detach(Log_rec &child)
 }
 
 void
-ANN::LS_set::reset()
+ANN::LS_set::commence()
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_reset(**it++);
+  while (it!=end) prop_commence(**it++);
 }
 
 void
-ANN::LS_set::prepare(size_t epoch)
+ANN::LS_set::open(size_t epoch)
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_prepare(**it++,epoch);
+  while (it!=end) prop_open(**it++,epoch);
 }
 
 void
-ANN::LS_set::stepped(size_t which_, const Loc *where_)
+ANN::LS_set::feed(size_t which_, const Loc *where_)
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_stepped(**it++,which_,where_);
+  while (it!=end) prop_feed(**it++,which_,where_);
 }
 
 void
-ANN::LS_set::update(size_t epoch)
+ANN::LS_set::close(size_t epoch)
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_update(**it++,epoch);
+  while (it!=end) prop_close(**it++,epoch);
 }
 
 void
-ANN::LS_set::finish(size_t epoch)
+ANN::LS_set::conclude(size_t epoch)
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_finish(**it++,epoch);
+  while (it!=end) prop_conclude(**it++,epoch);
 }
 
 void
-ANN::LS_set::finished(size_t epoch)
+ANN::LS_set::concluded(size_t epoch)
 {
   Iterator it=children.begin();
   Iterator end=children.end();
-  while (it!=end) prop_finished(**it++,epoch);
+  while (it!=end) prop_concluded(**it++,epoch);
 }
