@@ -20,6 +20,31 @@
 #include <stdio.h>
 
 #include <ann_parser_log.h>
+#include <ann_init.h>
+
+static char **
+mk_str_arr(const char * const *arr_)
+{
+  if (!arr_) return 0;
+  size_t i, n=0;
+  while (arr_[n]) ++n;
+  typedef char *Str;
+  char **arr=new Str[n+1];
+  for (i=0; i<n; ++i) arr[i]=ANN::Label::dup_str(arr_[i]);
+  arr[n]=0;
+  return arr;
+}
+
+static bool
+get_size_t(char *&str, size_t &val)
+{
+  char    buff[20];
+  size_t  i=0;
+  while ((i<sizeof(buff)-1) && ('0'<=*str) && (*str<='9')) buff[i++]=*str++;
+  if (!i || (i==sizeof(buff)-1)) return false;
+  buff[i]=0;
+  return sscanf(buff,"%lu",&val)==1;
+}
 
   //                       //
  // class ANN::Parser_log //
@@ -27,18 +52,44 @@
 
 #define PARSER_LOG_BUFF_LEN 1024
 
-ANN::Parser_log::Parser_log(std::istream &is_, char sublevel_beg,
-                            char sublevel_end, char sep_)
-: is(&is_), time(&Time::format), last_stamp(0), 
+ANN::Parser_log::Parser_log(const char *label_, std::istream &is_,
+                            char sublevel_beg, char sublevel_end, char sep_)
+: tc(TC::create()), is(&is_), time(&Time::format), last_stamp(0),
+  label(Label::dup_str(label_)), seq_labels(0),
   buff(new char[PARSER_LOG_BUFF_LEN]), pos(0), len(0), after_stamp(false)
 {
   set_separator(sep_);
   set_sublevel(sublevel_beg,sublevel_end);
 }
 
-ANN::Parser_log::Parser_log(std::istream &is_, Time &time_,
+ANN::Parser_log::Parser_log(const char *label_,
+                            const char * const * seq_labels_,
+                            std::istream &is_,
                             char sublevel_beg, char sublevel_end, char sep_)
-: is(&is_), time(&time_), last_stamp(0),
+: tc(TC::create()), is(&is_), time(&Time::format), last_stamp(0),
+  label(Label::dup_str(label_)), seq_labels(mk_str_arr(seq_labels_)),
+  buff(new char[PARSER_LOG_BUFF_LEN]), pos(0), len(0), after_stamp(false)
+{
+  set_separator(sep_);
+  set_sublevel(sublevel_beg,sublevel_end);
+}
+
+ANN::Parser_log::Parser_log(const char *label_, std::istream &is_, Time &time_,
+                            char sublevel_beg, char sublevel_end, char sep_)
+: tc(TC::create()), is(&is_), time(&time_), last_stamp(0),
+  label(Label::dup_str(label_)), seq_labels(0),
+  buff(new char[PARSER_LOG_BUFF_LEN]), pos(0), len(0), after_stamp(false)
+{
+  set_separator(sep_);
+  set_sublevel(sublevel_beg,sublevel_end);
+}
+
+ANN::Parser_log::Parser_log(const char *label_,
+                            const char * const * seq_labels_,
+                            std::istream &is_, Time &time_,
+                            char sublevel_beg, char sublevel_end, char sep_)
+: tc(TC::create()), is(&is_), time(&time_), last_stamp(0),
+  label(Label::dup_str(label_)), seq_labels(mk_str_arr(seq_labels_)),
   buff(new char[PARSER_LOG_BUFF_LEN]), pos(0), len(0), after_stamp(false)
 {
   set_separator(sep_);
@@ -47,10 +98,18 @@ ANN::Parser_log::Parser_log(std::istream &is_, Time &time_,
 
 ANN::Parser_log::~Parser_log()
 {
+  if (tc) delete tc;
+  if (label) delete [] label;
+  if (seq_labels)
+  {
+    const char * const * ptr=seq_labels;
+    while (*ptr) delete [] *ptr++;
+    delete [] seq_labels;
+  }
 }
 
 void
-ANN::Parser_log::add_word(const Loc &where, TC::Pos &pos_loc, TC &result,
+ANN::Parser_log::add_word(size_t seq, const Loc &where, TC::Pos &pos_loc,
                           size_t l)
 {
   char   tmp[20];
@@ -58,13 +117,13 @@ ANN::Parser_log::add_word(const Loc &where, TC::Pos &pos_loc, TC &result,
   int    i;
   Loc    loc;
   pos_loc.get_loc(loc);
-  if (l>=sizeof(tmp)-1) result.put(where,loc,NAN);
+  if (l>=sizeof(tmp)-1) tc->put(where,loc,NAN,seq);
   else
   {
     strncpy(tmp,buff+pos,l)[l]=0;
-    if (sscanf(tmp,"%lg",&d)==1) result.put(where,loc,d);
-    else if (sscanf(tmp,"%i",&i)==1) result.put(where,loc,i);
-    else result.put(where,loc,NAN);
+    if (sscanf(tmp,"%lg",&d)==1) tc->put(where,loc,d,seq);
+    else if (sscanf(tmp,"%i",&i)==1) tc->put(where,loc,i,seq);
+    else tc->put(where,loc,NAN,seq);
   }
   pos_loc.next();
 }
@@ -173,12 +232,12 @@ ANN::Parser_log::shift()
 }
 
 bool
-ANN::Parser_log::find(const char *label, char *&rest)
+ANN::Parser_log::find(const char *label_, char *&tail)
 {
   size_t i, j, l, p, llen;
   bool   ok;
   if (!after_stamp && !shift()) return false;
-  if (!(llen==(label ? strlen(label) : 0))) return true;
+  if (!(llen==(label_ ? strlen(label_) : 0))) return true;
   p=pos;
   for(;;)
   {
@@ -196,7 +255,7 @@ ANN::Parser_log::find(const char *label, char *&rest)
       }
     }
     j=p-pos;
-    while (p<len) if ((buff[p]=='\n') || (buff[p]!=label[j]))
+    while (p<len) if ((buff[p]=='\n') || (buff[p]!=label_[j]))
     {
       shift();
       p=pos;
@@ -261,10 +320,10 @@ ANN::Parser_log::find(const char *label, char *&rest)
         while ((l>pos) && (buff[l-1])==sep) --l;
         if (l-=pos)
         {
-          rest=new char[l+1];
-          strncpy(rest,buff+pos,l)[l]=0;
+          tail=new char[l+1];
+          strncpy(tail,buff+pos,l)[l]=0;
         }
-        else rest=0;
+        else tail=0;
         pos=p;
         return true;
       }
@@ -273,20 +332,87 @@ ANN::Parser_log::find(const char *label, char *&rest)
 }
 
 bool
-ANN::Parser_log::find(const char *label=0)
+ANN::Parser_log::find(const char *label_=0)
 {
-  char *rest;
+  char *tail;
   for (;;)
   {
-    rest=0;
-    if (!find(label,rest)) return false;
-    if (rest) delete [] rest;
+    tail=0;
+    if (!find(label_,tail)) return false;
+    if (tail) delete [] tail;
     else return true;
   }
 }
 
 bool
-ANN::Parser_log::load(const Loc &where, TC &result)
+ANN::Parser_log::parse(time_t end)
+{
+  char   *tail=0;
+  Loc     where;
+  size_t  seq, i, l;
+  while (*is && find(label,tail))
+  {
+    if ((end!=NAV_get(time_t)) && (end<last_stamp)) break;
+    if (tail)
+    {
+      if (seq_labels)
+      {
+        while (*is && seq_labels[seq])
+        {
+          while (tail[i] && (seq_labels[seq][i]==tail[i])) ++i;
+          if (!seq_labels[seq][i])
+          {
+            where.resize();
+            while (tail[i]==sep) ++i;            
+            if (tail[i])
+            {
+              char *str=tail+i;
+              if (('0'<=*str) && (*str<='9'))
+              {
+                if (!get_size_t(str,l)) break;
+                while (*str==sep) ++str;
+                if (*str && strncmp(str,"=>",2)) break;
+                while (*str==sep) ++str;
+                where << l;
+              }
+              if (*str) if (*str!='[') break;
+              else
+              {
+                where.resize();
+                while (*str)
+                {
+                  ++str;
+                  if (!get_size_t(str,l))
+                  {
+                    str=tail+i;
+                    break;
+                  }  
+                  where << l;
+                  if (*str!=',') break;
+                }
+                if (*str!=']') break;
+                if (*++str) break;
+              }
+              if (!load(seq,where)) tc->erase(where,seq);
+            }
+            break;
+          }  
+        }
+      }
+      delete [] tail;
+      tail=0;
+    }  
+    else
+    {
+      where.resize();
+      if (!seq_labels && !load(0,where)) tc->erase(where,0);
+    }  
+  }
+  return *is;  
+}
+
+bool
+ANN::Parser_log::load(size_t seq, const Loc &where)
 {
   size_t  i, l, p;
   bool    ok=true;
@@ -350,25 +476,25 @@ ANN::Parser_log::load(const Loc &where, TC &result)
     }
     while (p<len) if (buff[p]=='\n')
     {
-      if (l=p-pos) add_word(where,pos_loc,result,l);
+      if (l=p-pos) add_word(seq,where,pos_loc,l);
       pos=++p;
       after_stamp=false;
     }
     else if (buff[p]==sub_beg)
     {
-      if (l=p-pos) add_word(where,pos_loc,result,l);
+      if (l=p-pos) add_word(seq,where,pos_loc,l);
       pos=++p;
       pos_loc.inc_level();
     }
     else if (buff[p]==sub_end)
     {
-      if (l=p-pos) add_word(where,pos_loc,result,l);
+      if (l=p-pos) add_word(seq,where,pos_loc,l);
       pos=++p;
       if (!pos_loc.dec_level()) return true;
     }
     else if (buff[p]==sep)
     {
-      if (l=p-pos) add_word(where,pos_loc,result,l);
+      if (l=p-pos) add_word(seq,where,pos_loc,l);
       pos=++p;
     }
     else ++p;
