@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include <stdio.h>
+#include <string.h>
 
 #include <ann_parser_ws.h>
  
@@ -26,7 +27,7 @@
 #define PARSER_WS_BUFF_LEN 1024
 
 ANN::Parser_ws::Parser_ws()
-: in(TC::create()), des_out(TC::create()), is_out(false), was_val(false)
+: tc(TC::create()), seq(0), was_val(false)
 {
   pos_where.inc_level();
   pos_loc.inc_level();
@@ -34,8 +35,7 @@ ANN::Parser_ws::Parser_ws()
 
 ANN::Parser_ws::~Parser_ws()
 {
-  if (in) delete in;
-  if (des_out) delete des_out;
+  if (tc) delete tc;
 }
 
 void
@@ -47,7 +47,7 @@ ANN::Parser_ws::add_val(double x)
     was_val=true;
   }
   pos_loc.get_loc(loc);
-  (is_out ? des_out : in)->put(where,loc,x);
+  tc->put(where,loc,x,seq);
   pos_loc.next();
 }
 
@@ -85,16 +85,15 @@ ANN::Parser_ws::add_line()
     pos_loc.inc_level();
     was_val=false;
   }
-  is_out=false;
+  seq=0;
 }
 
-bool
-ANN::Parser_ws::des_out_patt()
+void
+ANN::Parser_ws::next_seq()
 {
-  if (is_out) return false;
   pos_loc.reset();
   pos_loc.inc_level();
-  return is_out=true;
+  ++seq;
 }
 
 bool
@@ -123,7 +122,7 @@ ANN::Parser_ws::internal_parse(std::istream &is)
     case '|':
       if (l=p-pos) if (!add_str(buff+pos,l)) return false;
       pos=++p;
-      if (!des_out_patt()) return false;
+      next_seq();
       break;
     case '\r':
     case '\n':
@@ -147,8 +146,7 @@ ANN::Parser_ws::parse(std::istream &is)
   if (ok) add_line();
   else
   {
-    in->shrink(last_good);
-    des_out->shrink(last_good);
+    tc->shrink(last_good);
     pos_where.reset(last_good);
   }  
   return ok;
