@@ -41,8 +41,11 @@ ANN::TC::Pos::dec_level()
  // class ANN::TC //
 //               //
 
+ANN::Size ANN::TC::none;
+
 ANN::TC::~TC()
 {
+  if (size) delete [] size;
 }
 
 void
@@ -51,32 +54,37 @@ ANN::TC::recalc()
   if (!lim_valid)
   {
     length.resize();
-    size.resize();
+    if (size)
+    {
+      delete [] size;
+      size=0;
+    }  
+    num_seq=0;
     do_recalc();
     lim_valid=true;
   }
 }
 
 void
-ANN::TC::put(const Loc &where, const Loc &loc, double val)
+ANN::TC::put(const Loc &where, const Loc &loc, double val, size_t seq)
 {
-  do_put(*new Token(where,loc,val));
+  do_put(*new Token(where,loc,val,seq));
   lim_valid=false;
 }
 
 double
-ANN::TC::get(const Loc &where, const Loc &loc)
+ANN::TC::get(const Loc &where, const Loc &loc, size_t seq)
 {
-  Token  t;
-  size_t i, j;
-  i=where.dim();
+  if (seq>=num_seq) return NAN;
+  Token  t(seq);
+  size_t i=where.dim(), j;
   for (;;)
   {
-    t.where.resize(i,where.coord());
+    t.where.resize(i,where.get_coord());
     j=loc.dim();
     for (;;)
     {
-      t.loc.resize(j,loc.coord());
+      t.loc.resize(j,loc.get_coord());
       if (do_get(t)) return t.val;
       if (!j) break;
       --j;
@@ -87,33 +95,49 @@ ANN::TC::get(const Loc &where, const Loc &loc)
   return NAN;
 }
 
-ANN::Term *
-ANN::TC::get_term(const Loc &where)
+ANN::TS *
+ANN::TC::build(size_t seq)
 {
-  Term   *term=new Term(size);
-  set_term(where,*term);
-  return term;
+  recalc();
+  if (seq>=num_seq) return 0;
+  TS     *ts=new TS(length,size[seq]);
+  double *data=ts->get_data();
+  Loc     where;
+  Loc     loc;
+  while (length.next(where)) while (size[seq].next(loc))
+    *data++=get(where,loc,seq);
+  return ts;
 }
 
 void
-ANN::TC::set_term(const Loc &where, Term &term)
+ANN::TC::build(Term &term, const Loc &where, size_t seq)
 {
-  double *data=term.get_data();
-  Loc     loc;
-  while (term.get_sizes().next(loc)) *data++=get(where,loc);
+  Token   t(where,seq);
+  double *data_=term.get_data();
+  while (term.get_sizes().next(t.loc)) *data_++=do_get(t);
 }
 
 void
 ANN::TC::shrink(const Loc &where)
 {
-  do_shrink(Token(where));
+  Token t(where);
+  do_shrink(t);
+  lim_valid=false;
+}
+
+void
+ANN::TC::erase(const Loc &where, size_t seq)
+{
+  Token t(where,seq);
+  do_erase(t);
   lim_valid=false;
 }
 
 void
 ANN::TC::erase(const Loc &where)
 {
-  do_erase(Token(where));
+  Token t(where);
+  for (t.seq=0; t.seq<num_seq; ++t.seq) do_erase(t);
   lim_valid=false;
 }
 
@@ -122,81 +146,11 @@ ANN::TC::clear()
 {
   do_clear();
   length.resize();
-  size.resize();
+  if (size)
+  {
+    delete [] size;
+    size=0;
+  }  
+  num_seq=0;
   lim_valid=true;
 }
-
-/*
-void
-ANN::TC::recalc_size()
-{
-  size_t i;
-  Size   tmp;
-  lim.resize(0,0);
-  for (i=0; i<num_term; ++i) if (calc_sizes(i,tmp)) lim.expand(tmp);
-  i=lim.dim();
-  while (i) if (lim[--i])
-  {
-    ++i;
-    break;
-  }
-  lim.resize(i);
-  lim_valid=true;
-}
-
-void
-ANN::TC::reset()
-{
-  l=size_max;
-  reserve(num_put);
-}
-
-void
-ANN::TC::inc_level()
-{
-  if (l==size_max)
-  {
-    l=0;
-    if (num_put>=num_term) num_term=num_put+1;
-  }
-  else ++l;
-  if (l==cur.dim()) cur.resize(l+1);
-  else cur[l]=0;
-}
-
-bool
-ANN::TC::dec_level()
-{
-  if (!l || (l==size_max))
-  {
-    put_next();
-    return false;
-  }
-  ++cur[--l];
-  lim_valid=false;
-  return true;
-}
-
-size_t
-ANN::TC::put_next()
-{
-  num_put=num_term;
-  reset();
-  return num_put;
-}
-
-void
-ANN::TC::put_at(size_t num)
-{
-  num_put=num;
-  reset();
-}
-
-bool
-ANN::TC::get_at(size_t num, Term &term)
-{
-  if (num>=num_term) return false;
-  num_get=num;
-  return get_next(term);
-}
-*/
