@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <vector>
+
 #include <ann_tc_set.h>
 
   //                   //
@@ -34,6 +36,7 @@ ANN::TC::create()
 bool
 ANN::TC_set::TokenCmp::operator ()(const Token *t1, const Token *t2) const
 {
+  if (t1->seq!=t2->seq) return t1->seq<t2->seq;
   short ret=t1->where.cmp(t2->where);
   return (ret ? ret : t1->loc.cmp(t2->loc))<0;
 }
@@ -46,13 +49,27 @@ ANN::TC_set::~TC_set()
 void
 ANN::TC_set::do_recalc()
 {
-  TSIterator it=tokens.begin();
-  TSIterator end=tokens.end();
+  std::vector<Size *>  size_;
+  TSIterator           it=tokens.begin();
+  TSIterator           end=tokens.end();
+  const Token         *ptr;
   while (it!=end)
   {
-    length.expand((*it)->where);
-    size.expand((*it++)->loc);
+    ptr=*it++;
+    length.expand(ptr->where);
+    if (ptr->seq>=num_seq) size_.resize(num_seq=ptr->seq+1,0);
+    if (!size_[ptr->seq]) size_[ptr->seq]=new Size;
+    size_[ptr->seq]->expand(ptr->loc);
   }
+  if (num_seq)
+  {
+    size=new Size[num_seq];
+    for (size_t i=0; i<num_seq; ++i) if (size_[i])
+    {
+      size[i]=*size_[i];
+      delete size_[i];
+    }  
+  }  
 }
 
 void
@@ -71,25 +88,27 @@ ANN::TC_set::do_get(Token &t)
 }
 
 void
-ANN::TC_set::do_shrink(const Token &t)
+ANN::TC_set::do_shrink(Token &t)
 {
   TSIterator   it;
   const Token *ptr;
-  while ((it=tokens.lower_bound(&t))!=tokens.end())
-  {
-    ptr=*it;
-    tokens.erase(it);
-    delete ptr;
-  }
+  for (t.seq=0; t.seq<num_seq; ++t.seq)
+    while ((it=tokens.lower_bound(&t))!=tokens.end())
+      if ((ptr=*it)->seq!=t.seq) break;
+      {
+        ptr=*it;
+        tokens.erase(it);
+        delete ptr;
+      }
 }
 
 void
-ANN::TC_set::do_erase(const Token &t)
+ANN::TC_set::do_erase(Token &t)
 {
   TSIterator   it;
   const Token *ptr;
   while ((it=tokens.lower_bound(&t))!=tokens.end())
-    if ((ptr=*it)->where!=t.where) break;
+    if (((ptr=*it)->seq!=t.seq) || ((ptr=*it)->where!=t.where)) break;
     else
     {
       tokens.erase(it);
@@ -110,127 +129,3 @@ ANN::TC_set::do_clear()
   }
 }
 
-/*
-static bool
-drop_set(ANN::TC_set::TokenSet *set)
-{
-  ANN::TC_set::TSIterator  it;
-  ANN::TC_set::Token      *ptr;
-  if (!set) return false;
-  while (!set->empty())
-  {
-    ptr=*(it=set->begin());
-    set->erase(it);
-    delete ptr;
-  }
-  delete set;
-  return true;
-}
-
-bool
-ANN::TC_set::calc_sizes(size_t num, Size &lim_)
-{
-  if (num>=num_term) return false;
-  lim_.resize(0,0);
-  if (tokens[num_get])
-  {
-    TSIterator  it=tokens[num_get]->begin();
-    TSIterator  end=tokens[num_get]->end();
-    while (it!=end) lim_.expand((*it++)->loc);
-  }
-  return true;  
-}
-
-void
-ANN::TC_set::reserve(size_t num)
-{
-  size_t i=tokens.size(), n;
-  if (num>=i)
-  {
-    tokens.resize(num+1);
-    for (n=tokens.size(); i<n; ++i) tokens[i]=0;
-  }
-}
-
-void
-ANN::TC_set::append(double d)
-{
-  if (!tokens[num_put]) tokens[num_put]=new TokenSet;
-  Token *ptr=new Token(l+1,cur.coord(),d);
-  tokens[num_put]->insert(ptr);
-  ++cur[l];
-  lim_valid=false;
-}
-
-bool
-ANN::TC_set::get_next(Term &term)
-{
-  if (!lim_valid) recalc_size();
-  bool   ret=(num_get<num_term);
-  size_t i, j=0, k;
-  Size   l_size(term.get_sizes());
-  l_size.expand(lim);
-  term.resize(l_size);
-  if (ret && tokens[num_get])
-  {
-    Token      *ptr;
-    Loc         l_it;
-    TSIterator  it=tokens[num_get]->begin();
-    TSIterator  end=tokens[num_get]->end();
-    while (it!=end)
-    {
-      ptr=*it++;
-      l_it=ptr->loc;
-      i=l_size[l_it];
-      for (k=j; k<i; ++k) term[k]=NAN;
-      j=l_it.dim();
-      while (j)
-      {
-        --j;
-        if (++l_it[j]==l_size[j]) l_it[j]=0; else break;
-      }
-      if (!(j=l_size[l_it])) j=l_size.total_size();
-      for (k=i; k<j; ++k) term[k]=ptr->d;
-    }
-  }
-  for (k=j, i=l_size.total_size(); k<i; ++k) term[k]=NAN;
-  if (ret) ++num_get;
-  return ret;
-}
-
-bool
-ANN::TC_set::erase(size_t num)
-{
-  if (num>=num_term) return false;
-  if (drop_set(tokens[num]))
-  {
-    tokens[num]=0;
-    lim_valid=false;
-  }
-  if (num==num_put) reset();
-  return true;
-}
-
-void
-ANN::TC_set::shrink()
-{
-  TokenSet *ts;
-  while (num_term>0) if (ts=tokens[--num_term]) if (ts->empty())
-  {
-    delete ts;
-    tokens[num_term]=0;
-  }
-  else
-  {
-    ++num_term;
-    break;
-  }
-  if (num_put>num_term)
-  {
-    num_put=num_term;
-    reset();
-  }
-  if (num_get>num_term) num_get=num_term;
-  tokens.resize(num_term+(num_put==num_term));
-}
-*/
