@@ -25,44 +25,21 @@ ANN::TO_online::~TO_online()
 {
 }
 
-size_t
-ANN::TO_online::train(size_t epochs)
-{
-  if (!ds || !elem || (ds->get_length()==size_max)) return 0;
-  size_t           epoch_=0, length;
-  Term             t_out(elem->get_out_sizes());
-  Term             t_err;
-  bool             is_superv=elem->is_supervised();
-  int              fin=0;
-  DS              *des_out=ds->des_output();
+ANN::NE::Status
+ANN::TO_online::adapt_internal()
+{  
+  if (log) log->open(epoch);
+  trainee->open();
   ds->reset();
-  length=ds->get_length();
-  while ((fin<1) && (epoch_<epochs))
+  for (size_t i=0, l=ds->get_length(); i<l; ++i)
   {
-    step=0;
-    fin=0;
-    if (log) log->prepare(epoch);
-    elem->prepare(*this);
-    for (;;)
-    {
-      if (log) log->stepped(step,&ds->where());
-      ws->prepare(*this);
-      elem->calc(ds->term(), t_out);
-      elem->adapt(ds->term(), t_out, is_superv ? &des_out->term() : 0, 0);
-      ws->update(*this);
-      if (length<=++step) break;
-      ds->next();
-    }
-    if (log) log->stepped(size_max,0);
-    fin=trained_state(fin,elem->update(*this));
-    if (log) log->update(epoch);
-    ++epoch;
-    ++epoch_;
-    if (!ds->reset()) ds->next();
+    if (i) ds->feed();
+    if (log) log->feed(which(),&where());
+    trainee->adapt(ds->term(),out_data);
+    ws->commit(*this);
   }
-  if (log) log->finish(epoch);
-  ws->finish(*this);
-  elem->finish(*this);
-  if (log) log->finished(epoch);
-  return epoch_;
+  if (log) log->feed(size_max,0);
+  Status ret=trainee->close();
+  if (log) log->close(epoch);
+  return ret;
 }
