@@ -26,12 +26,12 @@ ANN::W_static::~W_static()
 }
 
 void
-ANN::W_static::adapt(const Term &d_)
+ANN::W_static::feed_back(const Term &d_)
 {
 }
 
 void
-ANN::W_static::update(TO &t)
+ANN::W_static::commit(NE &ne)
 {
 }
 
