@@ -26,14 +26,14 @@ ANN::W_triv::~W_triv()
 }
 
 void
-ANN::W_triv::adapt(const Term &d_)
+ANN::W_triv::feed_back(const Term &d_)
 {
   size_t i, l=w.get_size();
   for (i=0; i<l; ++i) w.get_data()[i]=d_.get_data()[i];
 }
 
 void
-ANN::W_triv::update(TO &t)
+ANN::W_triv::commit(NE &ne)
 {
 }
 
