@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include <string.h>
+#include <stdlib.h>
 
 #include <ann_weight.h>
 
@@ -41,17 +42,17 @@ ANN::W::get_group() const
 }
 
 void
-ANN::W::reset(TO &t)
+ANN::W::reset(NE *ne)
 {
 }
 
 void
-ANN::W::prepare(TO &t)
+ANN::W::commence(NE &ne)
 {
 }
 
 void
-ANN::W::finish(TO &t)
+ANN::W::conclude(NE &ne)
 {
 }
 
@@ -67,17 +68,14 @@ ANN::W::randomize()
 bool
 ANN::W::load(Parser_log &parser, time_t begin, time_t end)
 {
+  parser.clear();
   if ((begin!=NAV_get(time_t)) && !parser.seek(begin)) return false;
   if (!parser.find(label)) return false;
   if ((end!=NAV_get(time_t)) && (end<parser.when())) return false;
-  TC   *tc=TC::create();
-  Loc   where(1);
-  bool  ret=parser.load(where,*tc);
-  if (ret) if ((end!=NAV_get(time_t)) && (end<parser.when())) ret=false;
-  else if (tc->get_sizes()!=w.get_sizes()) ret=false;
-  if (ret) tc->set_term(where,w);
-  delete tc;
-  return ret;
+  if (!parser(end)) return false;
+  if (parser.get_sizes(0)!=w.get_sizes()) return false;
+  parser.build(w,Loc(),0);
+  return true;
 }
 
 void
@@ -86,12 +84,14 @@ ANN::W::store(Log &log)
   log.log(w,label);
 }
 
+/*
 void
 ANN::W::drop_weights(WA &wa)
 {
   size_t i, n=wa.get_size();
   for (i=0; i<n; ++i) if (wa[i]) delete wa[i];
 }
+*/
 
   //               //
  // class ANN::WG //
@@ -110,7 +110,7 @@ ANN::WG::signature_find(Parser_log &parser, time_t begin, time_t end)
   size_t  l;
   bool    cont=true, ret;
   if ((begin!=NAV_get(time_t)) && !parser.seek(begin)) return false;
-  while (cont) 
+  while (cont)
   {
     tail=0;
     if (!parser.find(WGROUP_SIGNATURE,tail)) return false;
@@ -134,27 +134,32 @@ ANN::WG::signature_write(Log &log_, W &w)
 }
 
 void
-ANN::WG::reset(TO &t)
+ANN::WG::reset(NE *ne)
 {
 }
 
 void
-ANN::WG::prepare(TO &t)
+ANN::WG::reseted(NE *ne)
 {
 }
 
 void
-ANN::WG::prepared(TO &t)
+ANN::WG::commence(NE &ne)
 {
 }
 
 void
-ANN::WG::update(TO &t)
+ANN::WG::commenced(NE &ne)
 {
 }
 
 void
-ANN::WG::updated(TO &t)
+ANN::WG::commit(NE &ne)
+{
+}
+
+void
+ANN::WG::commited(NE &ne)
 {
   if (log)
   {
@@ -164,12 +169,12 @@ ANN::WG::updated(TO &t)
 }
 
 void
-ANN::WG::finish(TO &t)
+ANN::WG::conclude(NE &ne)
 {
 }
 
 void
-ANN::WG::finished(TO &t)
+ANN::WG::concluded(NE &ne)
 {
   if (log)
   {
