@@ -50,53 +50,55 @@ ANN::WS_set::erase_weights()
 }
 
 void
-ANN::WS_set::reset(TO &t)
+ANN::WS_set::reset(NE *ne)
 {
   WGs_it git, gend;
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->reset(t);
+    (*git)->reset(ne);
   Ws_it wit, wend;
   for (wit=w_set.begin(), wend=w_set.end(); wit!=wend; ++wit)
-    (*wit)->reset(t);
+    (*wit)->reset(ne);
+  for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
+    (*git)->reseted(ne);
 }
 
 void
-ANN::WS_set::prepare(TO &t)
+ANN::WS_set::commence(NE &ne)
 {
   WGs_it git, gend;
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->prepare(t);
+    (*git)->commence(ne);
   Ws_it wit, wend;
   for (wit=w_set.begin(), wend=w_set.end(); wit!=wend; ++wit)
-    (*wit)->prepare(t);
+    (*wit)->commence(ne);
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->prepared(t);
+    (*git)->commenced(ne);
 }
 
 void
-ANN::WS_set::update(TO &t)
+ANN::WS_set::commit(NE &ne)
 {
   WGs_it git, gend;
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->update(t);
+    (*git)->commit(ne);
   Ws_it wit, wend;
   for (wit=w_set.begin(), wend=w_set.end(); wit!=wend; ++wit)
-    (*wit)->update(t);
+    (*wit)->commit(ne);
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->updated(t);
+    (*git)->commited(ne);
 }
 
 void
-ANN::WS_set::finish(TO &t)
+ANN::WS_set::conclude(NE &ne)
 {
   WGs_it git, gend;
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->finish(t);
+    (*git)->conclude(ne);
   Ws_it wit, wend;
   for (wit=w_set.begin(), wend=w_set.end(); wit!=wend; ++wit)
-    (*wit)->finish(t);
+    (*wit)->conclude(ne);
   for (git=g_set.begin(), gend=g_set.end(); git!=gend; ++git)
-    (*git)->finished(t);
+    (*git)->concluded(ne);
 }
 
 void
